eprllib.Env.MultiAgent.EnergyPlusRunner — eprllib: use EnergyPlus as an environment for DRL control

Skip to main content
`Ctrl`+`K`

# eprllib.Env.MultiAgent.EnergyPlusRunner

# ENERGYPLUS RUNNER

This script contain the EnergyPlus Runner that execute EnergyPlus from its Python API in the version 23.2.0.

Classes

`EnergyPlusRunner`(episode, env_config, ...) | This object have the particularity of start EnergyPlus, _collect_obs and _send_actions to send it trhougt queue to the EnergyPlus Environment thread.